

from __future__ import print_function, unicode_literals, absolute_import, division
from reahl.doc.examples.tutorial.login1.login1 import LoginUI

web.site_root = LoginUI
